@@ -1,11 +1,15 @@
 from django.template import Library, Node, TemplateSyntaxError
 from django.utils.safestring import mark_safe
 import re
+import logging
+import requests
 
 from ..backends import detect_backend, VideoBackend
 
 register = Library()
 
+logger = logging.getLogger(__name__)
+
 
 @register.tag('video')
 class VideoNode(Node):
@@ -67,21 +71,34 @@ class VideoNode(Node):
     def render(self, context):
         url = self.url.resolve(context)
 
+        # Fixes #18. If no video url is provided it should return an empty
+        # string instead raising UnknownBackendException.
+        if not url:
+            return ''
+
         if self.size:
             return self.__render_embed(url, context)
         else:
             return self.__render_block(url, context)
 
     def __render_embed(self, url, context):
-        size = self.size.resolve(context)
+        size = self.size.resolve(context) \
+            if hasattr(self.size, 'resolve') else self.size
         return self.embed(url, size, context=context)
 
     def __render_block(self, url, context):
+        output = ''
         as_var = self.bits[-1]
-        context.push()
-        context[as_var] = self.get_backend(url, context=context)
-        output = self.nodelist_file.render(context)
-        context.pop()
+
+        try:
+            context.push()
+            context[as_var] = self.get_backend(url, context=context)
+            output = self.nodelist_file.render(context)
+            context.pop()
+        except requests.Timeout:
+            logger.exception('Timeout reached during rendering embed '
+                             'video (`{0}`)'.format(url))
+
         return output
 
     @staticmethod
